netapp_ontap.models.san API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.san`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SanSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the San object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `application_components: List[SanApplicationComponents] GET POST PATCH`

    The application_components field of the san.

  `exclude_aggregates: List[NasExcludeAggregates] GET POST`

    The exclude_aggregates field of the san.

  `new_igroups: List[SanNewIgroups] POST PATCH`

    The list of initiator groups to create.

  `os_type: str GET POST`

    The name of the host OS running the application.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - netware
    - openvms
    - solaris
    - solaris_efi
    - vmware
    - windows
    - windows_2008
    - windows_gpt
    - xen
  `protection_type: NasProtectionType GET POST PATCH`

    The protection_type field of the san.